@@ -1,5 +1,20 @@
 package App::Ack::Filter::Collection;
 
+=head1 NAME
+
+App::Ack::Filter::Collection
+
+=head1 DESCRIPTION
+
+The Ack::Filter::Collection class can contain filters and internally sort
+them into groups. The groups can then be optimized for faster filtering.
+
+Filters are grouped and replaced by a fast hash lookup. This leads to
+improved performance when many such filters are active, like when using
+the C<--known> command line option.
+
+=cut
+
 use strict;
 use warnings;
 use base 'App::Ack::Filter';
