@@ -6,6 +6,16 @@ use strict;
 use App::Ack ();
 
 
+=head1 NAME
+
+App::Ack::ConfigDefault
+
+=head1 DESCRIPTION
+
+A module that contains the default configuration for ack.
+
+=cut
+
 sub options {
     return split( /\n/, _options_block() );
 }
@@ -53,6 +63,8 @@ sub _options_block {
 # Git
 # http://git-scm.com/
 --ignore-directory=is:.git
+# When using submodules, .git is a file.
+--ignore-file=is:.git
 
 # Mercurial
 # http://mercurial.selenic.com/
@@ -293,6 +305,10 @@ sub _options_block {
 # http://www.json.org/
 --type-add=json:ext:json
 
+# Kotlin
+# https://kotlinlang.org/
+--type-add=kotlin:ext:kt,kts
+
 # Less
 # http://www.lesscss.org/
 --type-add=less:ext:less
