@@ -117,8 +117,11 @@ sub needs_line_scan {
     my $self  = shift;
     my $opt   = shift;
 
+    # Can't tell if it does NOT exist in the file.
     return 1 if $opt->{v};
 
+    return 1 unless -f $self->{fh};
+
     my $size = -s $self->{fh};
     if ( $size == 0 ) {
         return 0;
@@ -155,6 +158,10 @@ sub reset {
         return;
     }
 
+    if ( !-f $self->{fh} ) {
+        return;
+    }
+
     if ( !seek( $self->{fh}, 0, 0 ) && $App::Ack::report_bad_filenames ) {
         App::Ack::warn( "$self->{filename}: $!" );
     }
@@ -200,7 +207,7 @@ sub clone {
 }
 
 
-=head2 $res->firstliney
+=head2 $res->firstliney()
 
 Returns the first line of a file (or first 250 characters, whichever
 comes first).
@@ -210,9 +217,15 @@ comes first).
 sub firstliney {
     my ( $self ) = @_;
 
-    my $fh = $self->open();
-
     if ( !exists $self->{firstliney} ) {
+        my $fh = $self->open();
+        if ( !$fh ) {
+            if ( $App::Ack::report_bad_filenames ) {
+                App::Ack::warn( $self->name . ': ' . $! );
+            }
+            return '';
+        }
+
         my $buffer = '';
         my $rc     = sysread( $fh, $buffer, 250 );
         unless($rc) { # XXX handle this better?
@@ -221,9 +234,9 @@ sub firstliney {
         $buffer =~ s/[\r\n].*//s;
         $self->{firstliney} = $buffer;
         $self->reset;
-    }
 
-    $self->close;
+        $self->close;
+    }
 
     return $self->{firstliney};
 }
